==> hyphenate-sdk-lite-3.2.3-sources.jar: com/hyphenate/chat/adapter/EMACallManagerListener.java <==
package com.hyphenate.chat.adapter;

import com.superrtc.sdk.RtcConnection;

public class EMACallManagerListener extends EMABase implements EMACallManagerListenerInterface {

    public EMACallManagerListener() {
        nativeInit();
    }
    
    @Override
    public void finalize() throws Throwable {
        nativeFinalize();
        super.finalize();
    }
    
    /**
     * create native listener class which implements EMAChatManagerListener interface.
     */
    native void nativeInit();
    native void nativeFinalize();
    
    @Override
    public void onSendPushMessage(String from, String to) {}
    
    @Override
    public void onRecvCallFeatureUnsupported(EMACallSession session, EMAError error) {}
    
    @Override
    public void onRecvCallIncoming(EMACallSession callSession) {}
    
    @Override
    public void onRecvCallConnected(EMACallSession callSession) {}
    
    @Override
    public void onRecvCallAccepted(EMACallSession callSession) {}
    
    @Override
    public void onRecvCallEnded(EMACallSession callSession, /*EMACallSession.endReason*/int endReason, EMAError error) {}

    @Override
    public void onRecvCallNetworkStatusChanged(EMACallSession callSession, int toStatus) {}
    
    @Override
    public void onRecvCallStateChanged(EMACallSession callSession, int StreamControlType) {}
    
    @Override
    public void onNewRtcConnection(String callId, int mode, EMACallStream callStream, String to,
            RtcConnection.Listener listener, EMACallRtcImpl rtcImpl) {}
            
    @Override
    public void onConferenceMemberJoined(EMACallConference callConference, String enteredName) {}
    @Override
    public void onConferenceMemberLeaved(EMACallConference callConference, String exitedName) {}
    @Override
    public void onConferenceMemberPublished(EMACallConference callConference, String pubedName) {}
    @Override
    public void onConferenceMembersUpdated(EMACallConference callConference) {}
    //public native void onReceiveSessionInfoChanged(int sessionInfoType);

    @Override
    public void onConferenceStreamConnected(EMACallConference callSession, EMACallStream subedStream) {}

    @Override
    public void onConferenceStreamClosed(EMACallConference callSession, EMACallStream subedStream, EMAError error) {}

    @Override
    public void onConferenceClosed(EMACallConference callSession) {}
}

==> hyphenate-sdk-lite-3.4.0-sources.jar: com/hyphenate/chat/adapter/EMACallManagerListener.java <==
/*
 *  * EaseMob CONFIDENTIAL
 * __________________
 * Copyright (C) 2017 EaseMob Technologies. All rights reserved.
 *
 * NOTICE: All information contained herein is, and remains
 * the property of EaseMob Technologies.
 * Dissemination of this information or reproduction of this material
 * is strictly forbidden unless prior written permission is obtained
 * from EaseMob Technologies.
 */
package com.hyphenate.chat.adapter;

import com.superrtc.sdk.RtcConnection;

public class EMACallManagerListener extends EMABase implements EMACallManagerListenerInterface {

    public EMACallManagerListener() {
        nativeInit();
    }
    
    @Override
    public void finalize() throws Throwable {
        nativeFinalize();
        super.finalize();
    }
    
    /**
     * create native listener class which implements EMAChatManagerListener interface.
     */
    native void nativeInit();
    native void nativeFinalize();
    
    @Override
    public void onSendPushMessage(String from, String to) {}
    
    @Override
    public void onRecvCallFeatureUnsupported(EMACallSession session, EMAError error) {}
    
    @Override
    public void onRecvCallIncoming(EMACallSession callSession) {}
    
    @Override
    public void onRecvCallConnected(EMACallSession callSession) {}
    
    @Override
    public void onRecvCallAccepted(EMACallSession callSession) {}
    
    @Override
    public void onRecvCallEnded(EMACallSession callSession, /*EMACallSession.endReason*/int endReason, EMAError error) {}

    @Override
    public void onRecvCallNetworkStatusChanged(EMACallSession callSession, int toStatus) {}
    
    @Override
    public void onRecvCallStateChanged(EMACallSession callSession, int StreamControlType) {}
    
    @Override
    public void onNewRtcConnection(String callId, int mode, String to,
            RtcConnection.Listener listener, EMACallRtcImpl rtcImpl) {}
}
